#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 open-browser
version:              0.2.1.1
visibility:           public
id:                   open-browser-0.2.1.1-LxNiN4VEneo8bxQiPfYDai
key:                  open-browser-0.2.1.1-LxNiN4VEneo8bxQiPfYDai
license:              BSD-3-Clause
maintainer:           public@pilgrem.com
author:               rightfold
homepage:             https://github.com/mpilgrem/open-browser
synopsis:             Open a web browser from Haskell.
description:
    Open a web browser from Haskell. Currently BSD, Linux, OS X and Windows are
    supported.

category:             Web
abi:                  62dae4b723555bba3c3a38959c5ebf92
exposed:              True
exposed-modules:      Web.Browser
hidden-modules:       Web.Browser.Linux Web.Browser.OSX
import-dirs:          /usr/lib/ghc-9.6.6/site-local/open-browser-0.2.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/open-browser-0.2.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/open-browser-0.2.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-open-browser
hs-libraries:         HSopen-browser-0.2.1.1-LxNiN4VEneo8bxQiPfYDai
depends:              base-4.18.2.1 process-1.6.19.0
haddock-interfaces:
    /usr/share/doc/haskell-open-browser/html/open-browser.haddock

haddock-html:         /usr/share/doc/haskell-open-browser/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

